# BlackFoxPython

Python package for communication with BlackFoxWebAPI

- API version: v1
- Package version: 0.0.11

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage

### pip install

```sh
pip install blackfox
```

### pip install tar.gz

Download [blackfox-0.0.11.tar.gz](https://github.com/vodena/BlackFoxPython/raw/master/dist/blackfox-0.0.11.tar.gz)

```sh
pip install blackfox-0.0.11.tar.gz
```

You can install directly from Github

```sh
pip install git+https://github.com/vodena/BlackFoxPython.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/vodena/BlackFoxPython.git`)
Please note that blackfox depends on [BlackFoxApi](https://github.com/vodena/BlackFoxRestApiPython) which must be available for blackfox to work. This means that you may need to install it manually if pip or others doesn't install it automatically.

Then import the package:
```python
import blackfox 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import blackfox
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run examples




